@@ -1,11 +1,6 @@
 """HTTPX is well-tested, so we test only the features that are provided by injected http client settings"""
-
-import pytest
-
 from bitccl import VERSION, run
 
-pytestmark = pytest.mark.slow
-
 
 def test_user_agent():
     assert run(f"assert http.get('http://httpbin.org/user-agent').json() == {{'user-agent': 'bitccl/{VERSION}'}}") is None
